# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Roi.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Shape' not in _M_omero.model.__dict__:
    _M_omero.model._t_Shape = IcePy.declareClass('::omero::model::Shape')
    _M_omero.model._t_ShapePrx = IcePy.declareProxy('::omero::model::Shape')

if 'Image' not in _M_omero.model.__dict__:
    _M_omero.model._t_Image = IcePy.declareClass('::omero::model::Image')
    _M_omero.model._t_ImagePrx = IcePy.declareProxy('::omero::model::Image')

if 'OriginalFile' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFile = IcePy.declareClass('::omero::model::OriginalFile')
    _M_omero.model._t_OriginalFilePrx = IcePy.declareProxy('::omero::model::OriginalFile')

if 'FolderRoiLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_FolderRoiLink = IcePy.declareClass('::omero::model::FolderRoiLink')
    _M_omero.model._t_FolderRoiLinkPrx = IcePy.declareProxy('::omero::model::FolderRoiLink')

if 'Folder' not in _M_omero.model.__dict__:
    _M_omero.model._t_Folder = IcePy.declareClass('::omero::model::Folder')
    _M_omero.model._t_FolderPrx = IcePy.declareProxy('::omero::model::Folder')

if 'RoiAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_RoiAnnotationLink = IcePy.declareClass('::omero::model::RoiAnnotationLink')
    _M_omero.model._t_RoiAnnotationLinkPrx = IcePy.declareProxy('::omero::model::RoiAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_RoiShapesSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RoiShapesSeq = IcePy.defineSequence('::omero::model::RoiShapesSeq', (), _M_omero.model._t_Shape)

if '_t_RoiFolderLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RoiFolderLinksSeq = IcePy.defineSequence('::omero::model::RoiFolderLinksSeq', (), _M_omero.model._t_FolderRoiLink)

if '_t_RoiLinkedFolderSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RoiLinkedFolderSeq = IcePy.defineSequence('::omero::model::RoiLinkedFolderSeq', (), _M_omero.model._t_Folder)

if '_t_RoiAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RoiAnnotationLinksSeq = IcePy.defineSequence('::omero::model::RoiAnnotationLinksSeq', (), _M_omero.model._t_RoiAnnotationLink)

if '_t_RoiLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_RoiLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::RoiLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Roi' not in _M_omero.model.__dict__:
    _M_omero.model.Roi = Ice.createTempClass()
    class Roi(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _name=None, _shapesSeq=None, _shapesLoaded=False, _image=None, _source=None, _folderLinksSeq=None, _folderLinksLoaded=False, _folderLinksCountPerOwner=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _description=None):
            if Ice.getType(self) == _M_omero.model.Roi:
                raise RuntimeError('omero.model.Roi is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._name = _name
            self._shapesSeq = _shapesSeq
            self._shapesLoaded = _shapesLoaded
            self._image = _image
            self._source = _source
            self._folderLinksSeq = _folderLinksSeq
            self._folderLinksLoaded = _folderLinksLoaded
            self._folderLinksCountPerOwner = _folderLinksCountPerOwner
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner
            self._description = _description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Roi')

        def ice_id(self, current=None):
            return '::omero::model::Roi'

        def ice_staticId():
            return '::omero::model::Roi'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getName(self, current=None):
            pass

        def setName(self, theName, current=None):
            pass

        def unloadShapes(self, current=None):
            pass

        def sizeOfShapes(self, current=None):
            pass

        def copyShapes(self, current=None):
            pass

        def addShape(self, target, current=None):
            pass

        def addAllShapeSet(self, targets, current=None):
            pass

        def removeShape(self, theTarget, current=None):
            pass

        def removeAllShapeSet(self, targets, current=None):
            pass

        def clearShapes(self, current=None):
            pass

        def reloadShapes(self, toCopy, current=None):
            pass

        def getShape(self, index, current=None):
            pass

        def setShape(self, index, theElement, current=None):
            pass

        def getPrimaryShape(self, current=None):
            pass

        def setPrimaryShape(self, theElement, current=None):
            pass

        def getImage(self, current=None):
            pass

        def setImage(self, theImage, current=None):
            pass

        def getSource(self, current=None):
            pass

        def setSource(self, theSource, current=None):
            pass

        def unloadFolderLinks(self, current=None):
            pass

        def sizeOfFolderLinks(self, current=None):
            pass

        def copyFolderLinks(self, current=None):
            pass

        def addFolderRoiLink(self, target, current=None):
            pass

        def addAllFolderRoiLinkSet(self, targets, current=None):
            pass

        def removeFolderRoiLink(self, theTarget, current=None):
            pass

        def removeAllFolderRoiLinkSet(self, targets, current=None):
            pass

        def clearFolderLinks(self, current=None):
            pass

        def reloadFolderLinks(self, toCopy, current=None):
            pass

        def getFolderLinksCountPerOwner(self, current=None):
            pass

        def linkFolder(self, addition, current=None):
            pass

        def addFolderRoiLinkToBoth(self, link, bothSides, current=None):
            pass

        def findFolderRoiLink(self, removal, current=None):
            pass

        def unlinkFolder(self, removal, current=None):
            pass

        def removeFolderRoiLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedFolderList(self, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addRoiAnnotationLink(self, target, current=None):
            pass

        def addAllRoiAnnotationLinkSet(self, targets, current=None):
            pass

        def removeRoiAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllRoiAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addRoiAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findRoiAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeRoiAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def getDescription(self, current=None):
            pass

        def setDescription(self, theDescription, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Roi)

        __repr__ = __str__

    _M_omero.model.RoiPrx = Ice.createTempClass()
    class RoiPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Roi._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Roi._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Roi._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Roi._op_setVersion.end(self, _r)

        def getName(self, _ctx=None):
            return _M_omero.model.Roi._op_getName.invoke(self, ((), _ctx))

        def begin_getName(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getName.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getName(self, _r):
            return _M_omero.model.Roi._op_getName.end(self, _r)

        def setName(self, theName, _ctx=None):
            return _M_omero.model.Roi._op_setName.invoke(self, ((theName, ), _ctx))

        def begin_setName(self, theName, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setName.begin(self, ((theName, ), _response, _ex, _sent, _ctx))

        def end_setName(self, _r):
            return _M_omero.model.Roi._op_setName.end(self, _r)

        def unloadShapes(self, _ctx=None):
            return _M_omero.model.Roi._op_unloadShapes.invoke(self, ((), _ctx))

        def begin_unloadShapes(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_unloadShapes.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadShapes(self, _r):
            return _M_omero.model.Roi._op_unloadShapes.end(self, _r)

        def sizeOfShapes(self, _ctx=None):
            return _M_omero.model.Roi._op_sizeOfShapes.invoke(self, ((), _ctx))

        def begin_sizeOfShapes(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_sizeOfShapes.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfShapes(self, _r):
            return _M_omero.model.Roi._op_sizeOfShapes.end(self, _r)

        def copyShapes(self, _ctx=None):
            return _M_omero.model.Roi._op_copyShapes.invoke(self, ((), _ctx))

        def begin_copyShapes(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_copyShapes.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyShapes(self, _r):
            return _M_omero.model.Roi._op_copyShapes.end(self, _r)

        def addShape(self, target, _ctx=None):
            return _M_omero.model.Roi._op_addShape.invoke(self, ((target, ), _ctx))

        def begin_addShape(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addShape.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addShape(self, _r):
            return _M_omero.model.Roi._op_addShape.end(self, _r)

        def addAllShapeSet(self, targets, _ctx=None):
            return _M_omero.model.Roi._op_addAllShapeSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllShapeSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addAllShapeSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllShapeSet(self, _r):
            return _M_omero.model.Roi._op_addAllShapeSet.end(self, _r)

        def removeShape(self, theTarget, _ctx=None):
            return _M_omero.model.Roi._op_removeShape.invoke(self, ((theTarget, ), _ctx))

        def begin_removeShape(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeShape.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeShape(self, _r):
            return _M_omero.model.Roi._op_removeShape.end(self, _r)

        def removeAllShapeSet(self, targets, _ctx=None):
            return _M_omero.model.Roi._op_removeAllShapeSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllShapeSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeAllShapeSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllShapeSet(self, _r):
            return _M_omero.model.Roi._op_removeAllShapeSet.end(self, _r)

        def clearShapes(self, _ctx=None):
            return _M_omero.model.Roi._op_clearShapes.invoke(self, ((), _ctx))

        def begin_clearShapes(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_clearShapes.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearShapes(self, _r):
            return _M_omero.model.Roi._op_clearShapes.end(self, _r)

        def reloadShapes(self, toCopy, _ctx=None):
            return _M_omero.model.Roi._op_reloadShapes.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadShapes(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_reloadShapes.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadShapes(self, _r):
            return _M_omero.model.Roi._op_reloadShapes.end(self, _r)

        def getShape(self, index, _ctx=None):
            return _M_omero.model.Roi._op_getShape.invoke(self, ((index, ), _ctx))

        def begin_getShape(self, index, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getShape.begin(self, ((index, ), _response, _ex, _sent, _ctx))

        def end_getShape(self, _r):
            return _M_omero.model.Roi._op_getShape.end(self, _r)

        def setShape(self, index, theElement, _ctx=None):
            return _M_omero.model.Roi._op_setShape.invoke(self, ((index, theElement), _ctx))

        def begin_setShape(self, index, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setShape.begin(self, ((index, theElement), _response, _ex, _sent, _ctx))

        def end_setShape(self, _r):
            return _M_omero.model.Roi._op_setShape.end(self, _r)

        def getPrimaryShape(self, _ctx=None):
            return _M_omero.model.Roi._op_getPrimaryShape.invoke(self, ((), _ctx))

        def begin_getPrimaryShape(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getPrimaryShape.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPrimaryShape(self, _r):
            return _M_omero.model.Roi._op_getPrimaryShape.end(self, _r)

        def setPrimaryShape(self, theElement, _ctx=None):
            return _M_omero.model.Roi._op_setPrimaryShape.invoke(self, ((theElement, ), _ctx))

        def begin_setPrimaryShape(self, theElement, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setPrimaryShape.begin(self, ((theElement, ), _response, _ex, _sent, _ctx))

        def end_setPrimaryShape(self, _r):
            return _M_omero.model.Roi._op_setPrimaryShape.end(self, _r)

        def getImage(self, _ctx=None):
            return _M_omero.model.Roi._op_getImage.invoke(self, ((), _ctx))

        def begin_getImage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getImage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getImage(self, _r):
            return _M_omero.model.Roi._op_getImage.end(self, _r)

        def setImage(self, theImage, _ctx=None):
            return _M_omero.model.Roi._op_setImage.invoke(self, ((theImage, ), _ctx))

        def begin_setImage(self, theImage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setImage.begin(self, ((theImage, ), _response, _ex, _sent, _ctx))

        def end_setImage(self, _r):
            return _M_omero.model.Roi._op_setImage.end(self, _r)

        def getSource(self, _ctx=None):
            return _M_omero.model.Roi._op_getSource.invoke(self, ((), _ctx))

        def begin_getSource(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getSource.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSource(self, _r):
            return _M_omero.model.Roi._op_getSource.end(self, _r)

        def setSource(self, theSource, _ctx=None):
            return _M_omero.model.Roi._op_setSource.invoke(self, ((theSource, ), _ctx))

        def begin_setSource(self, theSource, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setSource.begin(self, ((theSource, ), _response, _ex, _sent, _ctx))

        def end_setSource(self, _r):
            return _M_omero.model.Roi._op_setSource.end(self, _r)

        def unloadFolderLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_unloadFolderLinks.invoke(self, ((), _ctx))

        def begin_unloadFolderLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_unloadFolderLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadFolderLinks(self, _r):
            return _M_omero.model.Roi._op_unloadFolderLinks.end(self, _r)

        def sizeOfFolderLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_sizeOfFolderLinks.invoke(self, ((), _ctx))

        def begin_sizeOfFolderLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_sizeOfFolderLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfFolderLinks(self, _r):
            return _M_omero.model.Roi._op_sizeOfFolderLinks.end(self, _r)

        def copyFolderLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_copyFolderLinks.invoke(self, ((), _ctx))

        def begin_copyFolderLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_copyFolderLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyFolderLinks(self, _r):
            return _M_omero.model.Roi._op_copyFolderLinks.end(self, _r)

        def addFolderRoiLink(self, target, _ctx=None):
            return _M_omero.model.Roi._op_addFolderRoiLink.invoke(self, ((target, ), _ctx))

        def begin_addFolderRoiLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addFolderRoiLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addFolderRoiLink(self, _r):
            return _M_omero.model.Roi._op_addFolderRoiLink.end(self, _r)

        def addAllFolderRoiLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Roi._op_addAllFolderRoiLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllFolderRoiLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addAllFolderRoiLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllFolderRoiLinkSet(self, _r):
            return _M_omero.model.Roi._op_addAllFolderRoiLinkSet.end(self, _r)

        def removeFolderRoiLink(self, theTarget, _ctx=None):
            return _M_omero.model.Roi._op_removeFolderRoiLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeFolderRoiLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeFolderRoiLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeFolderRoiLink(self, _r):
            return _M_omero.model.Roi._op_removeFolderRoiLink.end(self, _r)

        def removeAllFolderRoiLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Roi._op_removeAllFolderRoiLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllFolderRoiLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeAllFolderRoiLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllFolderRoiLinkSet(self, _r):
            return _M_omero.model.Roi._op_removeAllFolderRoiLinkSet.end(self, _r)

        def clearFolderLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_clearFolderLinks.invoke(self, ((), _ctx))

        def begin_clearFolderLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_clearFolderLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearFolderLinks(self, _r):
            return _M_omero.model.Roi._op_clearFolderLinks.end(self, _r)

        def reloadFolderLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Roi._op_reloadFolderLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadFolderLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_reloadFolderLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadFolderLinks(self, _r):
            return _M_omero.model.Roi._op_reloadFolderLinks.end(self, _r)

        def getFolderLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Roi._op_getFolderLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getFolderLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getFolderLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFolderLinksCountPerOwner(self, _r):
            return _M_omero.model.Roi._op_getFolderLinksCountPerOwner.end(self, _r)

        def linkFolder(self, addition, _ctx=None):
            return _M_omero.model.Roi._op_linkFolder.invoke(self, ((addition, ), _ctx))

        def begin_linkFolder(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_linkFolder.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkFolder(self, _r):
            return _M_omero.model.Roi._op_linkFolder.end(self, _r)

        def addFolderRoiLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Roi._op_addFolderRoiLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addFolderRoiLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addFolderRoiLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addFolderRoiLinkToBoth(self, _r):
            return _M_omero.model.Roi._op_addFolderRoiLinkToBoth.end(self, _r)

        def findFolderRoiLink(self, removal, _ctx=None):
            return _M_omero.model.Roi._op_findFolderRoiLink.invoke(self, ((removal, ), _ctx))

        def begin_findFolderRoiLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_findFolderRoiLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findFolderRoiLink(self, _r):
            return _M_omero.model.Roi._op_findFolderRoiLink.end(self, _r)

        def unlinkFolder(self, removal, _ctx=None):
            return _M_omero.model.Roi._op_unlinkFolder.invoke(self, ((removal, ), _ctx))

        def begin_unlinkFolder(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_unlinkFolder.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkFolder(self, _r):
            return _M_omero.model.Roi._op_unlinkFolder.end(self, _r)

        def removeFolderRoiLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Roi._op_removeFolderRoiLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeFolderRoiLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeFolderRoiLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeFolderRoiLinkFromBoth(self, _r):
            return _M_omero.model.Roi._op_removeFolderRoiLinkFromBoth.end(self, _r)

        def linkedFolderList(self, _ctx=None):
            return _M_omero.model.Roi._op_linkedFolderList.invoke(self, ((), _ctx))

        def begin_linkedFolderList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_linkedFolderList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedFolderList(self, _r):
            return _M_omero.model.Roi._op_linkedFolderList.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Roi._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Roi._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Roi._op_copyAnnotationLinks.end(self, _r)

        def addRoiAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Roi._op_addRoiAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addRoiAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addRoiAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addRoiAnnotationLink(self, _r):
            return _M_omero.model.Roi._op_addRoiAnnotationLink.end(self, _r)

        def addAllRoiAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Roi._op_addAllRoiAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllRoiAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addAllRoiAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllRoiAnnotationLinkSet(self, _r):
            return _M_omero.model.Roi._op_addAllRoiAnnotationLinkSet.end(self, _r)

        def removeRoiAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Roi._op_removeRoiAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeRoiAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeRoiAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeRoiAnnotationLink(self, _r):
            return _M_omero.model.Roi._op_removeRoiAnnotationLink.end(self, _r)

        def removeAllRoiAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Roi._op_removeAllRoiAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllRoiAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeAllRoiAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllRoiAnnotationLinkSet(self, _r):
            return _M_omero.model.Roi._op_removeAllRoiAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Roi._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Roi._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Roi._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Roi._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Roi._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Roi._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Roi._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Roi._op_linkAnnotation.end(self, _r)

        def addRoiAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Roi._op_addRoiAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addRoiAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_addRoiAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addRoiAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Roi._op_addRoiAnnotationLinkToBoth.end(self, _r)

        def findRoiAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Roi._op_findRoiAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findRoiAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_findRoiAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findRoiAnnotationLink(self, _r):
            return _M_omero.model.Roi._op_findRoiAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Roi._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Roi._op_unlinkAnnotation.end(self, _r)

        def removeRoiAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Roi._op_removeRoiAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeRoiAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_removeRoiAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeRoiAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Roi._op_removeRoiAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Roi._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Roi._op_linkedAnnotationList.end(self, _r)

        def getDescription(self, _ctx=None):
            return _M_omero.model.Roi._op_getDescription.invoke(self, ((), _ctx))

        def begin_getDescription(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_getDescription.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDescription(self, _r):
            return _M_omero.model.Roi._op_getDescription.end(self, _r)

        def setDescription(self, theDescription, _ctx=None):
            return _M_omero.model.Roi._op_setDescription.invoke(self, ((theDescription, ), _ctx))

        def begin_setDescription(self, theDescription, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Roi._op_setDescription.begin(self, ((theDescription, ), _response, _ex, _sent, _ctx))

        def end_setDescription(self, _r):
            return _M_omero.model.Roi._op_setDescription.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.RoiPrx.ice_checkedCast(proxy, '::omero::model::Roi', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.RoiPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Roi'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_RoiPrx = IcePy.defineProxy('::omero::model::Roi', RoiPrx)

    _M_omero.model._t_Roi = IcePy.declareClass('::omero::model::Roi')

    _M_omero.model._t_Roi = IcePy.defineClass('::omero::model::Roi', Roi, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_name', (), _M_omero._t_RString, False, 0),
        ('_shapesSeq', (), _M_omero.model._t_RoiShapesSeq, False, 0),
        ('_shapesLoaded', (), IcePy._t_bool, False, 0),
        ('_image', (), _M_omero.model._t_Image, False, 0),
        ('_source', (), _M_omero.model._t_OriginalFile, False, 0),
        ('_folderLinksSeq', (), _M_omero.model._t_RoiFolderLinksSeq, False, 0),
        ('_folderLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_folderLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_RoiAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0),
        ('_description', (), _M_omero._t_RString, False, 0)
    ))
    Roi._ice_type = _M_omero.model._t_Roi

    Roi._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Roi._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Roi._op_getName = IcePy.Operation('getName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Roi._op_setName = IcePy.Operation('setName', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Roi._op_unloadShapes = IcePy.Operation('unloadShapes', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Roi._op_sizeOfShapes = IcePy.Operation('sizeOfShapes', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Roi._op_copyShapes = IcePy.Operation('copyShapes', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RoiShapesSeq, False, 0), ())
    Roi._op_addShape = IcePy.Operation('addShape', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Shape, False, 0),), (), None, ())
    Roi._op_addAllShapeSet = IcePy.Operation('addAllShapeSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiShapesSeq, False, 0),), (), None, ())
    Roi._op_removeShape = IcePy.Operation('removeShape', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Shape, False, 0),), (), None, ())
    Roi._op_removeAllShapeSet = IcePy.Operation('removeAllShapeSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiShapesSeq, False, 0),), (), None, ())
    Roi._op_clearShapes = IcePy.Operation('clearShapes', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Roi._op_reloadShapes = IcePy.Operation('reloadShapes', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Roi, False, 0),), (), None, ())
    Roi._op_getShape = IcePy.Operation('getShape', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0),), (), ((), _M_omero.model._t_Shape, False, 0), ())
    Roi._op_setShape = IcePy.Operation('setShape', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), IcePy._t_int, False, 0), ((), _M_omero.model._t_Shape, False, 0)), (), ((), _M_omero.model._t_Shape, False, 0), ())
    Roi._op_getPrimaryShape = IcePy.Operation('getPrimaryShape', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Shape, False, 0), ())
    Roi._op_setPrimaryShape = IcePy.Operation('setPrimaryShape', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Shape, False, 0),), (), ((), _M_omero.model._t_Shape, False, 0), ())
    Roi._op_getImage = IcePy.Operation('getImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Image, False, 0), ())
    Roi._op_setImage = IcePy.Operation('setImage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Image, False, 0),), (), None, ())
    Roi._op_getSource = IcePy.Operation('getSource', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_OriginalFile, False, 0), ())
    Roi._op_setSource = IcePy.Operation('setSource', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    Roi._op_unloadFolderLinks = IcePy.Operation('unloadFolderLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Roi._op_sizeOfFolderLinks = IcePy.Operation('sizeOfFolderLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Roi._op_copyFolderLinks = IcePy.Operation('copyFolderLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RoiFolderLinksSeq, False, 0), ())
    Roi._op_addFolderRoiLink = IcePy.Operation('addFolderRoiLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FolderRoiLink, False, 0),), (), None, ())
    Roi._op_addAllFolderRoiLinkSet = IcePy.Operation('addAllFolderRoiLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiFolderLinksSeq, False, 0),), (), None, ())
    Roi._op_removeFolderRoiLink = IcePy.Operation('removeFolderRoiLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FolderRoiLink, False, 0),), (), None, ())
    Roi._op_removeAllFolderRoiLinkSet = IcePy.Operation('removeAllFolderRoiLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiFolderLinksSeq, False, 0),), (), None, ())
    Roi._op_clearFolderLinks = IcePy.Operation('clearFolderLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Roi._op_reloadFolderLinks = IcePy.Operation('reloadFolderLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Roi, False, 0),), (), None, ())
    Roi._op_getFolderLinksCountPerOwner = IcePy.Operation('getFolderLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Roi._op_linkFolder = IcePy.Operation('linkFolder', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Folder, False, 0),), (), ((), _M_omero.model._t_FolderRoiLink, False, 0), ())
    Roi._op_addFolderRoiLinkToBoth = IcePy.Operation('addFolderRoiLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FolderRoiLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Roi._op_findFolderRoiLink = IcePy.Operation('findFolderRoiLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Folder, False, 0),), (), ((), _M_omero.model._t_RoiFolderLinksSeq, False, 0), ())
    Roi._op_unlinkFolder = IcePy.Operation('unlinkFolder', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Folder, False, 0),), (), None, ())
    Roi._op_removeFolderRoiLinkFromBoth = IcePy.Operation('removeFolderRoiLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_FolderRoiLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Roi._op_linkedFolderList = IcePy.Operation('linkedFolderList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RoiLinkedFolderSeq, False, 0), ())
    Roi._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Roi._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Roi._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RoiAnnotationLinksSeq, False, 0), ())
    Roi._op_addRoiAnnotationLink = IcePy.Operation('addRoiAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiAnnotationLink, False, 0),), (), None, ())
    Roi._op_addAllRoiAnnotationLinkSet = IcePy.Operation('addAllRoiAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiAnnotationLinksSeq, False, 0),), (), None, ())
    Roi._op_removeRoiAnnotationLink = IcePy.Operation('removeRoiAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiAnnotationLink, False, 0),), (), None, ())
    Roi._op_removeAllRoiAnnotationLinkSet = IcePy.Operation('removeAllRoiAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiAnnotationLinksSeq, False, 0),), (), None, ())
    Roi._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Roi._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Roi, False, 0),), (), None, ())
    Roi._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Roi._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_RoiAnnotationLink, False, 0), ())
    Roi._op_addRoiAnnotationLinkToBoth = IcePy.Operation('addRoiAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Roi._op_findRoiAnnotationLink = IcePy.Operation('findRoiAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_RoiAnnotationLinksSeq, False, 0), ())
    Roi._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Roi._op_removeRoiAnnotationLinkFromBoth = IcePy.Operation('removeRoiAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RoiAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Roi._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RoiLinkedAnnotationSeq, False, 0), ())
    Roi._op_getDescription = IcePy.Operation('getDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Roi._op_setDescription = IcePy.Operation('setDescription', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Roi = Roi
    del Roi

    _M_omero.model.RoiPrx = RoiPrx
    del RoiPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2013 University of Dundee & Open Microscopy Environment.
# All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from builtins import object
import pytest

import omero
from omero.cli import CLI
from omero.plugins.sessions import SessionsControl
from omero.rtypes import rstring

from omero.testlib import ITest
from mox3 import mox

class AbstractCLITest(ITest):

    @classmethod
    def setup_class(cls):
        super(AbstractCLITest, cls).setup_class()
        cls.cli = CLI()
        cls.cli.register("sessions", SessionsControl, "TEST")

    def setup_mock(self):
        self.mox = mox.Mox()

    def teardown_mock(self):
        self.mox.UnsetStubs()
        self.mox.VerifyAll()


class CLITest(AbstractCLITest):

    def setup_method(self, method):
        self.args = self.login_args()

    def create_object(self, object_type, name=""):
        # create object
        if object_type == 'Dataset':
            new_object = omero.model.DatasetI()
        elif object_type == 'Project':
            new_object = omero.model.ProjectI()
        elif object_type == 'Plate':
            new_object = omero.model.PlateI()
        elif object_type == 'Screen':
            new_object = omero.model.ScreenI()
        elif object_type == 'Image':
            new_object = self.new_image()
        new_object.name = rstring(name)
        new_object = self.update.saveAndReturnObject(new_object)

        # check object has been created
        found_object = self.query.get(object_type, new_object.id.val)
        assert found_object.id.val == new_object.id.val

        return new_object.id.val

    @pytest.fixture()
    def simpleHierarchy(self):
        proj = self.make_project()
        dset = self.make_dataset()
        img = self.update.saveAndReturnObject(self.new_image())
        self.link(proj, dset)
        self.link(dset, img)
        return proj, dset, img


class RootCLITest(AbstractCLITest):

    def setup_method(self, method):
        self.args = self.root_login_args()


class ArgumentFixture(object):

    """
    Used to test the user/group argument
    """

    def __init__(self, prefix, attr):
        self.prefix = prefix
        self.attr = attr

    def get_arguments(self, obj):
        args = []
        if self.prefix:
            args += [self.prefix]
        if self.attr:
            args += ["%s" % getattr(obj, self.attr).val]
        return args

    def __repr__(self):
        if self.prefix:
            return "%s" % self.prefix
        else:
            return "%s" % self.attr


UserIdNameFixtures = (
    ArgumentFixture('--id', 'id'),
    ArgumentFixture('--name', 'omeName'),
    )

UserFixtures = (
    ArgumentFixture(None, 'id'),
    ArgumentFixture(None, 'omeName'),
    ArgumentFixture('--user-id', 'id'),
    ArgumentFixture('--user-name', 'omeName'),
    )

GroupIdNameFixtures = (
    ArgumentFixture('--id', 'id'),
    ArgumentFixture('--name', 'name'),
    )

GroupFixtures = (
    ArgumentFixture(None, 'id'),
    ArgumentFixture(None, 'name'),
    ArgumentFixture('--group-id', 'id'),
    ArgumentFixture('--group-name', 'name'),
    )


def get_user_ids(out, sort_key=None):
    columns = {'login': 1, 'first-name': 2, 'last-name': 3, 'email': 4}
    lines = out.split('\n')
    ids = []
    last_value = None
    for line in lines[2:]:
        elements = line.split('|')
        if len(elements) < 8:
            continue

        ids.append(int(elements[0].strip()))
        if sort_key:
            if sort_key == 'id':
                new_value = ids[-1]
            else:
                new_value = elements[columns[sort_key]].strip()
            if last_value is not None:
                assert new_value >= last_value
            last_value = new_value
    return ids


def get_group_ids(out, sort_key=None):
    lines = out.split('\n')
    ids = []
    last_value = None
    for line in lines[2:]:
        elements = line.split('|')
        if len(elements) < 4:
            continue

        ids.append(int(elements[0].strip()))
        if sort_key:
            if sort_key == 'id':
                new_value = ids[-1]
            else:
                new_value = elements[1].strip()
            if last_value is not None:
                assert new_value >= last_value
            last_value = new_value
    return ids



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright 2009-2015 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt

"""
   Group administration plugin
"""

from builtins import str
import sys

from omero.cli import UserGroupControl, CLI, ExceptionHandler, admin_only
from omero.model.enums import AdminPrivilegeModifyGroup

HELP = """Group administration methods"""
defaultperms = {
    'private': 'rw----',
    'read-only': 'rwr---',
    'read-annotate': 'rwra--',
    'read-write': 'rwrw--'}


class GroupControl(UserGroupControl):

    def _configure(self, parser):

        self.exc = ExceptionHandler()

        PERM_TXT = """

Group permissions come in several styles:

    * private       (rw----)   [DEFAULT]
    * read-only     (rwr---)
    * read-annotate (rwra--)   [Previously known as 'collaborative']
    * read-write    (rwrw--)

In private groups, only group owners and system administrators will be
able to view someone else's data. In read-only groups, other group members
can see data but not annotate or modify it. In read-annotate groups,
annotation is permitted by group members. In read-write groups, all
group members can behave as if they co-own all the data.

Changing a group to private unlinks data from other users' containers and
unlinks other users' annotations from data. The change to private will
fail if different users' data is too closely related to be separated.

More information is available at:
https://docs.openmicroscopy.org/latest/omero/sysadmins/\
server-permissions.html
        """

        parser.add_login_arguments()
        sub = parser.sub()
        add = parser.add(sub, self.add,
                         "Add a new group with given permissions " + PERM_TXT)
        add.add_argument(
            "--ignore-existing", action="store_true", default=False,
            help="Do not fail if user already exists")
        add.add_argument("name", help="Name of the group")
        self.add_permissions_arguments(add)

        perms = parser.add(sub, self.perms,
                           "Modify a group's permissions " + PERM_TXT)
        self.add_id_name_arguments(perms, "group")
        self.add_permissions_arguments(perms)

        list = parser.add(
            sub, self.list, help="List information about all groups")

        info = parser.add(
            sub, self.info,
            "List information about the group(s). Default to the context"
            " group")
        self.add_group_arguments(info)

        for x in (list, info):
            x.add_style_argument()
            x.add_user_print_arguments()
            x.add_group_sorting_arguments()

        listusers = parser.add(
            sub, self.listusers, "List users of the current group")
        self.add_group_arguments(listusers)
        listusers.add_style_argument()
        listusers.add_group_print_arguments()
        listusers.add_user_sorting_arguments()

        copyusers = parser.add(sub, self.copyusers, "Copy the users of one"
                               " group to another group")
        copyusers.add_argument("from_group", help="ID or name of the source"
                               " group whose users will be copied")
        copyusers.add_argument("to_group", help="ID or name of the target"
                               " group which will have new users added")
        copyusers.add_argument(
            "--as-owner", action="store_true",
            default=False, help="Copy the group owners only")

        adduser = parser.add(sub, self.adduser,
                             "Add one or more users to a group")
        self.add_id_name_arguments(adduser, "group")
        group = self.add_user_arguments(
            adduser, action=" to add to the group")
        group.add_argument("--as-owner", action="store_true", default=False,
                           help="Add the users as owners of the group")

        removeuser = parser.add(sub, self.removeuser,
                                "Remove one or more users from a group")
        self.add_id_name_arguments(removeuser, "group")
        group = self.add_user_arguments(
            removeuser, action=" to remove from the group")
        group.add_argument("--as-owner", action="store_true", default=False,
                           help="Remove the users from the group owner list")

        for x in (add, perms, list, copyusers, adduser, removeuser):
            x.add_login_arguments()

    def add_permissions_arguments(self, parser):
        group = parser.add_mutually_exclusive_group()
        group.add_argument(
            "--perms", help="Group permissions set as string, e.g. 'rw----' ")
        group.add_argument(
            "--type", help="Group permissions set symbolically",
            default="private", choices=list(defaultperms.keys()))

    def parse_perms(self, args):
        from omero_model_PermissionsI import PermissionsI as Perms
        perms = getattr(args, "perms", None)
        if not perms:
            perms = defaultperms[args.type]
        try:
            return Perms(perms)
        except ValueError as ve:
            self.ctx.die(505, str(ve))

    @admin_only(AdminPrivilegeModifyGroup)
    def add(self, args):

        import omero
        from omero.rtypes import rbool, rstring
        from omero_model_ExperimenterGroupI import ExperimenterGroupI as Grp

        perms = self.parse_perms(args)
        c = self.ctx.conn(args)
        g = Grp()
        g.name = rstring(args.name)
        g.ldap = rbool(False)
        g.details.permissions = perms
        admin = c.getSession().getAdminService()
        try:
            grp = admin.lookupGroup(args.name)
            if grp:
                if args.ignore_existing:
                    self.ctx.out("Group exists: %s (id=%s)"
                                 % (args.name, grp.id.val))
                    return
                else:
                    self.ctx.die(3, "Group exists: %s (id=%s)"
                                 % (args.name, grp.id.val))
        except omero.ApiUsageException:
            pass  # Apparently no such group exists

        try:
            id = admin.createGroup(g)
            self.ctx.out("Added group %s (id=%s) with permissions %s"
                         % (args.name, id, perms))
        except omero.ValidationException as ve:
            # Possible, though unlikely after previous check
            if self.exc.is_constraint_violation(ve):
                self.ctx.die(66, "Group already exists: %s" % args.name)
            else:
                self.ctx.die(67, "Unknown ValidationException: %s"
                             % ve.message)
        except omero.SecurityViolation as se:
            self.ctx.die(68, "Security violation: %s" % se.message)
        except omero.ServerError as se:
            self.ctx.die(4, "%s: %s" % (type(se), se.message))

    def perms(self, args):

        import omero

        perms = self.parse_perms(args)
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()

        gid, g = self.parse_groupid(a, args)

        old_perms = str(g.details.permissions)
        if old_perms == str(perms):
            self.ctx.out("Permissions for group %s (id=%s) already %s"
                         % (g.name.val, gid, perms))
        else:
            try:
                chmod = omero.cmd.Chmod2(
                    targetObjects={'ExperimenterGroup': [gid]},
                    permissions=str(perms))
                c.submit(chmod)
                self.ctx.out("Changed permissions for group %s (id=%s) to %s"
                             % (g.name.val, gid, perms))
            except omero.CmdError as ce:
                import traceback
                self.ctx.dbg(traceback.format_exc())
                self.ctx.die(504, "Cannot change permissions for group %s"
                             " (id=%s) to %s: %s"
                             % (g.name.val, gid, perms, ce.err))

    def list(self, args):
        c = self.ctx.conn(args)
        groups = c.sf.getAdminService().lookupGroups()
        self.output_groups_list(groups, args)

    def info(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        [gid, groups] = self.list_groups(a, args, use_context=True)
        self.output_groups_list(groups, args)

    def listusers(self, args):
        c = self.ctx.conn(args)
        admin = c.sf.getAdminService()
        [gids, groups] = self.list_groups(admin, args, use_context=True)
        if len(gids) != 1:
            self.ctx.die(516, 'Too many group arguments')
        users = admin.containedExperimenters(gids[0])
        self.output_users_list(admin, users, args)

    def parse_groupid(self, a, args):
        if args.id:
            group = getattr(args, "id", None)
            return self.find_group_by_id(a, group, fatal=True)
        elif args.name:
            group = getattr(args, "name", None)
            return self.find_group_by_name(a, group, fatal=True)
        else:
            self.error_no_input_group(fatal=True)

    def filter_users(self, uids, group, owner=False, join=True):

        if owner:
            uid_list = self.getownerids(group)
            relation = "owner of"
        else:
            uid_list = self.getuserids(group)
            relation = "in"

        for uid in list(uids):
            if join:
                if uid in uid_list:
                    self.ctx.out("%s is already %s group %s"
                                 % (uid, relation, group.id.val))
                    uids.remove(uid)
            else:
                if uid not in uid_list:
                    self.ctx.out("%s is not %s group %s"
                                 % (uid, relation, group.id.val))
                    uids.remove(uid)
        return uids

    def copyusers(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        f_gid, f_grp = self.find_group(a, args.from_group, fatal=True)
        t_gid, t_grp = self.find_group(a, args.to_group, fatal=True)

        if args.as_owner:
            uids = self.getownerids(f_grp)
        else:
            uids = self.getuserids(f_grp)
        uids = self.filter_users(uids, t_grp, args.as_owner, True)

        if args.as_owner:
            self.addownersbyid(a, t_grp, uids)
            self.ctx.out("Owners of %s copied to %s"
                         % (args.from_group, args.to_group))
        else:
            self.addusersbyid(a, t_grp, uids)
            self.ctx.out("Users of %s copied to %s"
                         % (args.from_group, args.to_group))

    def adduser(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        group = self.parse_groupid(a, args)[1]
        [uids, users] = self.list_users(a, args, use_context=False)
        uids = self.filter_users(uids, group, args.as_owner, True)

        if args.as_owner:
            self.addownersbyid(a, group, uids)
        else:
            self.addusersbyid(a, group, uids)

    def removeuser(self, args):
        c = self.ctx.conn(args)
        a = c.sf.getAdminService()
        group = self.parse_groupid(a, args)[1]
        [uids, users] = self.list_users(a, args, use_context=False)
        uids = self.filter_users(uids, group, args.as_owner, False)

        if args.as_owner:
            self.removeownersbyid(a, group, uids)
        else:
            self.removeusersbyid(a, group, uids)

try:
    register("group", GroupControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("group", GroupControl, HELP)
        cli.invoke(sys.argv[1:])



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# OMERO Processor Runner
# Copyright 2009 Glencoe Software, Inc.  All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#

import sys
import Ice
import omero

from omero.processor import ProcessorI

if __name__ == "__main__":
    app = omero.util.Server(
        ProcessorI, "ProcessorAdapter", Ice.Identity("Processor", ""))
    sys.exit(app.main(sys.argv))




#
# Copyright 2012 Glencoe Software, Inc. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt
#


import Ice

class AcquisitionModeObjectFactory(Ice.ObjectFactory):

    from omero_model_AcquisitionModeI import AcquisitionModeI

    def create(self, type):
        return self.AcquisitionModeI()

    def destroy(self):
        pass

class AdminPrivilegeObjectFactory(Ice.ObjectFactory):

    from omero_model_AdminPrivilegeI import AdminPrivilegeI

    def create(self, type):
        return self.AdminPrivilegeI()

    def destroy(self):
        pass

class AffineTransformObjectFactory(Ice.ObjectFactory):

    from omero_model_AffineTransformI import AffineTransformI

    def create(self, type):
        return self.AffineTransformI()

    def destroy(self):
        pass

class AnnotationAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_AnnotationAnnotationLinkI import AnnotationAnnotationLinkI

    def create(self, type):
        return self.AnnotationAnnotationLinkI()

    def destroy(self):
        pass

class ArcObjectFactory(Ice.ObjectFactory):

    from omero_model_ArcI import ArcI

    def create(self, type):
        return self.ArcI()

    def destroy(self):
        pass

class ArcTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_ArcTypeI import ArcTypeI

    def create(self, type):
        return self.ArcTypeI()

    def destroy(self):
        pass

class BinningObjectFactory(Ice.ObjectFactory):

    from omero_model_BinningI import BinningI

    def create(self, type):
        return self.BinningI()

    def destroy(self):
        pass

class BooleanAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_BooleanAnnotationI import BooleanAnnotationI

    def create(self, type):
        return self.BooleanAnnotationI()

    def destroy(self):
        pass

class ChannelObjectFactory(Ice.ObjectFactory):

    from omero_model_ChannelI import ChannelI

    def create(self, type):
        return self.ChannelI()

    def destroy(self):
        pass

class ChannelAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ChannelAnnotationLinkI import ChannelAnnotationLinkI

    def create(self, type):
        return self.ChannelAnnotationLinkI()

    def destroy(self):
        pass

class ChannelBindingObjectFactory(Ice.ObjectFactory):

    from omero_model_ChannelBindingI import ChannelBindingI

    def create(self, type):
        return self.ChannelBindingI()

    def destroy(self):
        pass

class ChecksumAlgorithmObjectFactory(Ice.ObjectFactory):

    from omero_model_ChecksumAlgorithmI import ChecksumAlgorithmI

    def create(self, type):
        return self.ChecksumAlgorithmI()

    def destroy(self):
        pass

class CommentAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_CommentAnnotationI import CommentAnnotationI

    def create(self, type):
        return self.CommentAnnotationI()

    def destroy(self):
        pass

class ContrastMethodObjectFactory(Ice.ObjectFactory):

    from omero_model_ContrastMethodI import ContrastMethodI

    def create(self, type):
        return self.ContrastMethodI()

    def destroy(self):
        pass

class ContrastStretchingContextObjectFactory(Ice.ObjectFactory):

    from omero_model_ContrastStretchingContextI import ContrastStretchingContextI

    def create(self, type):
        return self.ContrastStretchingContextI()

    def destroy(self):
        pass

class CorrectionObjectFactory(Ice.ObjectFactory):

    from omero_model_CorrectionI import CorrectionI

    def create(self, type):
        return self.CorrectionI()

    def destroy(self):
        pass

class DBPatchObjectFactory(Ice.ObjectFactory):

    from omero_model_DBPatchI import DBPatchI

    def create(self, type):
        return self.DBPatchI()

    def destroy(self):
        pass

class DatasetObjectFactory(Ice.ObjectFactory):

    from omero_model_DatasetI import DatasetI

    def create(self, type):
        return self.DatasetI()

    def destroy(self):
        pass

class DatasetAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_DatasetAnnotationLinkI import DatasetAnnotationLinkI

    def create(self, type):
        return self.DatasetAnnotationLinkI()

    def destroy(self):
        pass

class DatasetImageLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_DatasetImageLinkI import DatasetImageLinkI

    def create(self, type):
        return self.DatasetImageLinkI()

    def destroy(self):
        pass

class DetectorObjectFactory(Ice.ObjectFactory):

    from omero_model_DetectorI import DetectorI

    def create(self, type):
        return self.DetectorI()

    def destroy(self):
        pass

class DetectorAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_DetectorAnnotationLinkI import DetectorAnnotationLinkI

    def create(self, type):
        return self.DetectorAnnotationLinkI()

    def destroy(self):
        pass

class DetectorSettingsObjectFactory(Ice.ObjectFactory):

    from omero_model_DetectorSettingsI import DetectorSettingsI

    def create(self, type):
        return self.DetectorSettingsI()

    def destroy(self):
        pass

class DetectorTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_DetectorTypeI import DetectorTypeI

    def create(self, type):
        return self.DetectorTypeI()

    def destroy(self):
        pass

class DichroicObjectFactory(Ice.ObjectFactory):

    from omero_model_DichroicI import DichroicI

    def create(self, type):
        return self.DichroicI()

    def destroy(self):
        pass

class DichroicAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_DichroicAnnotationLinkI import DichroicAnnotationLinkI

    def create(self, type):
        return self.DichroicAnnotationLinkI()

    def destroy(self):
        pass

class DimensionOrderObjectFactory(Ice.ObjectFactory):

    from omero_model_DimensionOrderI import DimensionOrderI

    def create(self, type):
        return self.DimensionOrderI()

    def destroy(self):
        pass

class DoubleAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_DoubleAnnotationI import DoubleAnnotationI

    def create(self, type):
        return self.DoubleAnnotationI()

    def destroy(self):
        pass

class EllipseObjectFactory(Ice.ObjectFactory):

    from omero_model_EllipseI import EllipseI

    def create(self, type):
        return self.EllipseI()

    def destroy(self):
        pass

class EventObjectFactory(Ice.ObjectFactory):

    from omero_model_EventI import EventI

    def create(self, type):
        return self.EventI()

    def destroy(self):
        pass

class EventLogObjectFactory(Ice.ObjectFactory):

    from omero_model_EventLogI import EventLogI

    def create(self, type):
        return self.EventLogI()

    def destroy(self):
        pass

class EventTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_EventTypeI import EventTypeI

    def create(self, type):
        return self.EventTypeI()

    def destroy(self):
        pass

class ExperimentObjectFactory(Ice.ObjectFactory):

    from omero_model_ExperimentI import ExperimentI

    def create(self, type):
        return self.ExperimentI()

    def destroy(self):
        pass

class ExperimentTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_ExperimentTypeI import ExperimentTypeI

    def create(self, type):
        return self.ExperimentTypeI()

    def destroy(self):
        pass

class ExperimenterObjectFactory(Ice.ObjectFactory):

    from omero_model_ExperimenterI import ExperimenterI

    def create(self, type):
        return self.ExperimenterI()

    def destroy(self):
        pass

class ExperimenterAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ExperimenterAnnotationLinkI import ExperimenterAnnotationLinkI

    def create(self, type):
        return self.ExperimenterAnnotationLinkI()

    def destroy(self):
        pass

class ExperimenterGroupObjectFactory(Ice.ObjectFactory):

    from omero_model_ExperimenterGroupI import ExperimenterGroupI

    def create(self, type):
        return self.ExperimenterGroupI()

    def destroy(self):
        pass

class ExperimenterGroupAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ExperimenterGroupAnnotationLinkI import ExperimenterGroupAnnotationLinkI

    def create(self, type):
        return self.ExperimenterGroupAnnotationLinkI()

    def destroy(self):
        pass

class ExternalInfoObjectFactory(Ice.ObjectFactory):

    from omero_model_ExternalInfoI import ExternalInfoI

    def create(self, type):
        return self.ExternalInfoI()

    def destroy(self):
        pass

class FamilyObjectFactory(Ice.ObjectFactory):

    from omero_model_FamilyI import FamilyI

    def create(self, type):
        return self.FamilyI()

    def destroy(self):
        pass

class FilamentObjectFactory(Ice.ObjectFactory):

    from omero_model_FilamentI import FilamentI

    def create(self, type):
        return self.FilamentI()

    def destroy(self):
        pass

class FilamentTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_FilamentTypeI import FilamentTypeI

    def create(self, type):
        return self.FilamentTypeI()

    def destroy(self):
        pass

class FileAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_FileAnnotationI import FileAnnotationI

    def create(self, type):
        return self.FileAnnotationI()

    def destroy(self):
        pass

class FilesetObjectFactory(Ice.ObjectFactory):

    from omero_model_FilesetI import FilesetI

    def create(self, type):
        return self.FilesetI()

    def destroy(self):
        pass

class FilesetAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FilesetAnnotationLinkI import FilesetAnnotationLinkI

    def create(self, type):
        return self.FilesetAnnotationLinkI()

    def destroy(self):
        pass

class FilesetEntryObjectFactory(Ice.ObjectFactory):

    from omero_model_FilesetEntryI import FilesetEntryI

    def create(self, type):
        return self.FilesetEntryI()

    def destroy(self):
        pass

class FilesetJobLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FilesetJobLinkI import FilesetJobLinkI

    def create(self, type):
        return self.FilesetJobLinkI()

    def destroy(self):
        pass

class FilterObjectFactory(Ice.ObjectFactory):

    from omero_model_FilterI import FilterI

    def create(self, type):
        return self.FilterI()

    def destroy(self):
        pass

class FilterAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FilterAnnotationLinkI import FilterAnnotationLinkI

    def create(self, type):
        return self.FilterAnnotationLinkI()

    def destroy(self):
        pass

class FilterSetObjectFactory(Ice.ObjectFactory):

    from omero_model_FilterSetI import FilterSetI

    def create(self, type):
        return self.FilterSetI()

    def destroy(self):
        pass

class FilterSetEmissionFilterLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FilterSetEmissionFilterLinkI import FilterSetEmissionFilterLinkI

    def create(self, type):
        return self.FilterSetEmissionFilterLinkI()

    def destroy(self):
        pass

class FilterSetExcitationFilterLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FilterSetExcitationFilterLinkI import FilterSetExcitationFilterLinkI

    def create(self, type):
        return self.FilterSetExcitationFilterLinkI()

    def destroy(self):
        pass

class FilterTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_FilterTypeI import FilterTypeI

    def create(self, type):
        return self.FilterTypeI()

    def destroy(self):
        pass

class FolderObjectFactory(Ice.ObjectFactory):

    from omero_model_FolderI import FolderI

    def create(self, type):
        return self.FolderI()

    def destroy(self):
        pass

class FolderAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FolderAnnotationLinkI import FolderAnnotationLinkI

    def create(self, type):
        return self.FolderAnnotationLinkI()

    def destroy(self):
        pass

class FolderImageLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FolderImageLinkI import FolderImageLinkI

    def create(self, type):
        return self.FolderImageLinkI()

    def destroy(self):
        pass

class FolderRoiLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_FolderRoiLinkI import FolderRoiLinkI

    def create(self, type):
        return self.FolderRoiLinkI()

    def destroy(self):
        pass

class FormatObjectFactory(Ice.ObjectFactory):

    from omero_model_FormatI import FormatI

    def create(self, type):
        return self.FormatI()

    def destroy(self):
        pass

class GenericExcitationSourceObjectFactory(Ice.ObjectFactory):

    from omero_model_GenericExcitationSourceI import GenericExcitationSourceI

    def create(self, type):
        return self.GenericExcitationSourceI()

    def destroy(self):
        pass

class GroupExperimenterMapObjectFactory(Ice.ObjectFactory):

    from omero_model_GroupExperimenterMapI import GroupExperimenterMapI

    def create(self, type):
        return self.GroupExperimenterMapI()

    def destroy(self):
        pass

class IlluminationObjectFactory(Ice.ObjectFactory):

    from omero_model_IlluminationI import IlluminationI

    def create(self, type):
        return self.IlluminationI()

    def destroy(self):
        pass

class ImageObjectFactory(Ice.ObjectFactory):

    from omero_model_ImageI import ImageI

    def create(self, type):
        return self.ImageI()

    def destroy(self):
        pass

class ImageAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ImageAnnotationLinkI import ImageAnnotationLinkI

    def create(self, type):
        return self.ImageAnnotationLinkI()

    def destroy(self):
        pass

class ImagingEnvironmentObjectFactory(Ice.ObjectFactory):

    from omero_model_ImagingEnvironmentI import ImagingEnvironmentI

    def create(self, type):
        return self.ImagingEnvironmentI()

    def destroy(self):
        pass

class ImmersionObjectFactory(Ice.ObjectFactory):

    from omero_model_ImmersionI import ImmersionI

    def create(self, type):
        return self.ImmersionI()

    def destroy(self):
        pass

class ImportJobObjectFactory(Ice.ObjectFactory):

    from omero_model_ImportJobI import ImportJobI

    def create(self, type):
        return self.ImportJobI()

    def destroy(self):
        pass

class IndexingJobObjectFactory(Ice.ObjectFactory):

    from omero_model_IndexingJobI import IndexingJobI

    def create(self, type):
        return self.IndexingJobI()

    def destroy(self):
        pass

class InstrumentObjectFactory(Ice.ObjectFactory):

    from omero_model_InstrumentI import InstrumentI

    def create(self, type):
        return self.InstrumentI()

    def destroy(self):
        pass

class InstrumentAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_InstrumentAnnotationLinkI import InstrumentAnnotationLinkI

    def create(self, type):
        return self.InstrumentAnnotationLinkI()

    def destroy(self):
        pass

class IntegrityCheckJobObjectFactory(Ice.ObjectFactory):

    from omero_model_IntegrityCheckJobI import IntegrityCheckJobI

    def create(self, type):
        return self.IntegrityCheckJobI()

    def destroy(self):
        pass

class JobOriginalFileLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_JobOriginalFileLinkI import JobOriginalFileLinkI

    def create(self, type):
        return self.JobOriginalFileLinkI()

    def destroy(self):
        pass

class JobStatusObjectFactory(Ice.ObjectFactory):

    from omero_model_JobStatusI import JobStatusI

    def create(self, type):
        return self.JobStatusI()

    def destroy(self):
        pass

class LabelObjectFactory(Ice.ObjectFactory):

    from omero_model_LabelI import LabelI

    def create(self, type):
        return self.LabelI()

    def destroy(self):
        pass

class LaserObjectFactory(Ice.ObjectFactory):

    from omero_model_LaserI import LaserI

    def create(self, type):
        return self.LaserI()

    def destroy(self):
        pass

class LaserMediumObjectFactory(Ice.ObjectFactory):

    from omero_model_LaserMediumI import LaserMediumI

    def create(self, type):
        return self.LaserMediumI()

    def destroy(self):
        pass

class LaserTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_LaserTypeI import LaserTypeI

    def create(self, type):
        return self.LaserTypeI()

    def destroy(self):
        pass

class LightEmittingDiodeObjectFactory(Ice.ObjectFactory):

    from omero_model_LightEmittingDiodeI import LightEmittingDiodeI

    def create(self, type):
        return self.LightEmittingDiodeI()

    def destroy(self):
        pass

class LightPathObjectFactory(Ice.ObjectFactory):

    from omero_model_LightPathI import LightPathI

    def create(self, type):
        return self.LightPathI()

    def destroy(self):
        pass

class LightPathAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_LightPathAnnotationLinkI import LightPathAnnotationLinkI

    def create(self, type):
        return self.LightPathAnnotationLinkI()

    def destroy(self):
        pass

class LightPathEmissionFilterLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_LightPathEmissionFilterLinkI import LightPathEmissionFilterLinkI

    def create(self, type):
        return self.LightPathEmissionFilterLinkI()

    def destroy(self):
        pass

class LightPathExcitationFilterLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_LightPathExcitationFilterLinkI import LightPathExcitationFilterLinkI

    def create(self, type):
        return self.LightPathExcitationFilterLinkI()

    def destroy(self):
        pass

class LightSettingsObjectFactory(Ice.ObjectFactory):

    from omero_model_LightSettingsI import LightSettingsI

    def create(self, type):
        return self.LightSettingsI()

    def destroy(self):
        pass

class LightSourceAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_LightSourceAnnotationLinkI import LightSourceAnnotationLinkI

    def create(self, type):
        return self.LightSourceAnnotationLinkI()

    def destroy(self):
        pass

class LineObjectFactory(Ice.ObjectFactory):

    from omero_model_LineI import LineI

    def create(self, type):
        return self.LineI()

    def destroy(self):
        pass

class LinkObjectFactory(Ice.ObjectFactory):

    from omero_model_LinkI import LinkI

    def create(self, type):
        return self.LinkI()

    def destroy(self):
        pass

class ListAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_ListAnnotationI import ListAnnotationI

    def create(self, type):
        return self.ListAnnotationI()

    def destroy(self):
        pass

class LogicalChannelObjectFactory(Ice.ObjectFactory):

    from omero_model_LogicalChannelI import LogicalChannelI

    def create(self, type):
        return self.LogicalChannelI()

    def destroy(self):
        pass

class LongAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_LongAnnotationI import LongAnnotationI

    def create(self, type):
        return self.LongAnnotationI()

    def destroy(self):
        pass

class MapAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_MapAnnotationI import MapAnnotationI

    def create(self, type):
        return self.MapAnnotationI()

    def destroy(self):
        pass

class MaskObjectFactory(Ice.ObjectFactory):

    from omero_model_MaskI import MaskI

    def create(self, type):
        return self.MaskI()

    def destroy(self):
        pass

class MediumObjectFactory(Ice.ObjectFactory):

    from omero_model_MediumI import MediumI

    def create(self, type):
        return self.MediumI()

    def destroy(self):
        pass

class MetadataImportJobObjectFactory(Ice.ObjectFactory):

    from omero_model_MetadataImportJobI import MetadataImportJobI

    def create(self, type):
        return self.MetadataImportJobI()

    def destroy(self):
        pass

class MicrobeamManipulationObjectFactory(Ice.ObjectFactory):

    from omero_model_MicrobeamManipulationI import MicrobeamManipulationI

    def create(self, type):
        return self.MicrobeamManipulationI()

    def destroy(self):
        pass

class MicrobeamManipulationTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_MicrobeamManipulationTypeI import MicrobeamManipulationTypeI

    def create(self, type):
        return self.MicrobeamManipulationTypeI()

    def destroy(self):
        pass

class MicroscopeObjectFactory(Ice.ObjectFactory):

    from omero_model_MicroscopeI import MicroscopeI

    def create(self, type):
        return self.MicroscopeI()

    def destroy(self):
        pass

class MicroscopeTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_MicroscopeTypeI import MicroscopeTypeI

    def create(self, type):
        return self.MicroscopeTypeI()

    def destroy(self):
        pass

class NamespaceObjectFactory(Ice.ObjectFactory):

    from omero_model_NamespaceI import NamespaceI

    def create(self, type):
        return self.NamespaceI()

    def destroy(self):
        pass

class NamespaceAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_NamespaceAnnotationLinkI import NamespaceAnnotationLinkI

    def create(self, type):
        return self.NamespaceAnnotationLinkI()

    def destroy(self):
        pass

class NodeObjectFactory(Ice.ObjectFactory):

    from omero_model_NodeI import NodeI

    def create(self, type):
        return self.NodeI()

    def destroy(self):
        pass

class NodeAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_NodeAnnotationLinkI import NodeAnnotationLinkI

    def create(self, type):
        return self.NodeAnnotationLinkI()

    def destroy(self):
        pass

class OTFObjectFactory(Ice.ObjectFactory):

    from omero_model_OTFI import OTFI

    def create(self, type):
        return self.OTFI()

    def destroy(self):
        pass

class ObjectiveObjectFactory(Ice.ObjectFactory):

    from omero_model_ObjectiveI import ObjectiveI

    def create(self, type):
        return self.ObjectiveI()

    def destroy(self):
        pass

class ObjectiveAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ObjectiveAnnotationLinkI import ObjectiveAnnotationLinkI

    def create(self, type):
        return self.ObjectiveAnnotationLinkI()

    def destroy(self):
        pass

class ObjectiveSettingsObjectFactory(Ice.ObjectFactory):

    from omero_model_ObjectiveSettingsI import ObjectiveSettingsI

    def create(self, type):
        return self.ObjectiveSettingsI()

    def destroy(self):
        pass

class OriginalFileObjectFactory(Ice.ObjectFactory):

    from omero_model_OriginalFileI import OriginalFileI

    def create(self, type):
        return self.OriginalFileI()

    def destroy(self):
        pass

class OriginalFileAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_OriginalFileAnnotationLinkI import OriginalFileAnnotationLinkI

    def create(self, type):
        return self.OriginalFileAnnotationLinkI()

    def destroy(self):
        pass

class ParseJobObjectFactory(Ice.ObjectFactory):

    from omero_model_ParseJobI import ParseJobI

    def create(self, type):
        return self.ParseJobI()

    def destroy(self):
        pass

class PathObjectFactory(Ice.ObjectFactory):

    from omero_model_PathI import PathI

    def create(self, type):
        return self.PathI()

    def destroy(self):
        pass

class PhotometricInterpretationObjectFactory(Ice.ObjectFactory):

    from omero_model_PhotometricInterpretationI import PhotometricInterpretationI

    def create(self, type):
        return self.PhotometricInterpretationI()

    def destroy(self):
        pass

class PixelDataJobObjectFactory(Ice.ObjectFactory):

    from omero_model_PixelDataJobI import PixelDataJobI

    def create(self, type):
        return self.PixelDataJobI()

    def destroy(self):
        pass

class PixelsObjectFactory(Ice.ObjectFactory):

    from omero_model_PixelsI import PixelsI

    def create(self, type):
        return self.PixelsI()

    def destroy(self):
        pass

class PixelsOriginalFileMapObjectFactory(Ice.ObjectFactory):

    from omero_model_PixelsOriginalFileMapI import PixelsOriginalFileMapI

    def create(self, type):
        return self.PixelsOriginalFileMapI()

    def destroy(self):
        pass

class PixelsTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_PixelsTypeI import PixelsTypeI

    def create(self, type):
        return self.PixelsTypeI()

    def destroy(self):
        pass

class PlaneInfoObjectFactory(Ice.ObjectFactory):

    from omero_model_PlaneInfoI import PlaneInfoI

    def create(self, type):
        return self.PlaneInfoI()

    def destroy(self):
        pass

class PlaneInfoAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_PlaneInfoAnnotationLinkI import PlaneInfoAnnotationLinkI

    def create(self, type):
        return self.PlaneInfoAnnotationLinkI()

    def destroy(self):
        pass

class PlaneSlicingContextObjectFactory(Ice.ObjectFactory):

    from omero_model_PlaneSlicingContextI import PlaneSlicingContextI

    def create(self, type):
        return self.PlaneSlicingContextI()

    def destroy(self):
        pass

class PlateObjectFactory(Ice.ObjectFactory):

    from omero_model_PlateI import PlateI

    def create(self, type):
        return self.PlateI()

    def destroy(self):
        pass

class PlateAcquisitionObjectFactory(Ice.ObjectFactory):

    from omero_model_PlateAcquisitionI import PlateAcquisitionI

    def create(self, type):
        return self.PlateAcquisitionI()

    def destroy(self):
        pass

class PlateAcquisitionAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_PlateAcquisitionAnnotationLinkI import PlateAcquisitionAnnotationLinkI

    def create(self, type):
        return self.PlateAcquisitionAnnotationLinkI()

    def destroy(self):
        pass

class PlateAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_PlateAnnotationLinkI import PlateAnnotationLinkI

    def create(self, type):
        return self.PlateAnnotationLinkI()

    def destroy(self):
        pass

class PointObjectFactory(Ice.ObjectFactory):

    from omero_model_PointI import PointI

    def create(self, type):
        return self.PointI()

    def destroy(self):
        pass

class PolygonObjectFactory(Ice.ObjectFactory):

    from omero_model_PolygonI import PolygonI

    def create(self, type):
        return self.PolygonI()

    def destroy(self):
        pass

class PolylineObjectFactory(Ice.ObjectFactory):

    from omero_model_PolylineI import PolylineI

    def create(self, type):
        return self.PolylineI()

    def destroy(self):
        pass

class ProjectObjectFactory(Ice.ObjectFactory):

    from omero_model_ProjectI import ProjectI

    def create(self, type):
        return self.ProjectI()

    def destroy(self):
        pass

class ProjectAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ProjectAnnotationLinkI import ProjectAnnotationLinkI

    def create(self, type):
        return self.ProjectAnnotationLinkI()

    def destroy(self):
        pass

class ProjectDatasetLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ProjectDatasetLinkI import ProjectDatasetLinkI

    def create(self, type):
        return self.ProjectDatasetLinkI()

    def destroy(self):
        pass

class ProjectionAxisObjectFactory(Ice.ObjectFactory):

    from omero_model_ProjectionAxisI import ProjectionAxisI

    def create(self, type):
        return self.ProjectionAxisI()

    def destroy(self):
        pass

class ProjectionDefObjectFactory(Ice.ObjectFactory):

    from omero_model_ProjectionDefI import ProjectionDefI

    def create(self, type):
        return self.ProjectionDefI()

    def destroy(self):
        pass

class ProjectionTypeObjectFactory(Ice.ObjectFactory):

    from omero_model_ProjectionTypeI import ProjectionTypeI

    def create(self, type):
        return self.ProjectionTypeI()

    def destroy(self):
        pass

class PulseObjectFactory(Ice.ObjectFactory):

    from omero_model_PulseI import PulseI

    def create(self, type):
        return self.PulseI()

    def destroy(self):
        pass

class QuantumDefObjectFactory(Ice.ObjectFactory):

    from omero_model_QuantumDefI import QuantumDefI

    def create(self, type):
        return self.QuantumDefI()

    def destroy(self):
        pass

class ReagentObjectFactory(Ice.ObjectFactory):

    from omero_model_ReagentI import ReagentI

    def create(self, type):
        return self.ReagentI()

    def destroy(self):
        pass

class ReagentAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ReagentAnnotationLinkI import ReagentAnnotationLinkI

    def create(self, type):
        return self.ReagentAnnotationLinkI()

    def destroy(self):
        pass

class RectangleObjectFactory(Ice.ObjectFactory):

    from omero_model_RectangleI import RectangleI

    def create(self, type):
        return self.RectangleI()

    def destroy(self):
        pass

class RenderingDefObjectFactory(Ice.ObjectFactory):

    from omero_model_RenderingDefI import RenderingDefI

    def create(self, type):
        return self.RenderingDefI()

    def destroy(self):
        pass

class RenderingModelObjectFactory(Ice.ObjectFactory):

    from omero_model_RenderingModelI import RenderingModelI

    def create(self, type):
        return self.RenderingModelI()

    def destroy(self):
        pass

class ReverseIntensityContextObjectFactory(Ice.ObjectFactory):

    from omero_model_ReverseIntensityContextI import ReverseIntensityContextI

    def create(self, type):
        return self.ReverseIntensityContextI()

    def destroy(self):
        pass

class RoiObjectFactory(Ice.ObjectFactory):

    from omero_model_RoiI import RoiI

    def create(self, type):
        return self.RoiI()

    def destroy(self):
        pass

class RoiAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_RoiAnnotationLinkI import RoiAnnotationLinkI

    def create(self, type):
        return self.RoiAnnotationLinkI()

    def destroy(self):
        pass

class ScreenObjectFactory(Ice.ObjectFactory):

    from omero_model_ScreenI import ScreenI

    def create(self, type):
        return self.ScreenI()

    def destroy(self):
        pass

class ScreenAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ScreenAnnotationLinkI import ScreenAnnotationLinkI

    def create(self, type):
        return self.ScreenAnnotationLinkI()

    def destroy(self):
        pass

class ScreenPlateLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ScreenPlateLinkI import ScreenPlateLinkI

    def create(self, type):
        return self.ScreenPlateLinkI()

    def destroy(self):
        pass

class ScriptJobObjectFactory(Ice.ObjectFactory):

    from omero_model_ScriptJobI import ScriptJobI

    def create(self, type):
        return self.ScriptJobI()

    def destroy(self):
        pass

class SessionObjectFactory(Ice.ObjectFactory):

    from omero_model_SessionI import SessionI

    def create(self, type):
        return self.SessionI()

    def destroy(self):
        pass

class SessionAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_SessionAnnotationLinkI import SessionAnnotationLinkI

    def create(self, type):
        return self.SessionAnnotationLinkI()

    def destroy(self):
        pass

class ShapeAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_ShapeAnnotationLinkI import ShapeAnnotationLinkI

    def create(self, type):
        return self.ShapeAnnotationLinkI()

    def destroy(self):
        pass

class ShareObjectFactory(Ice.ObjectFactory):

    from omero_model_ShareI import ShareI

    def create(self, type):
        return self.ShareI()

    def destroy(self):
        pass

class ShareMemberObjectFactory(Ice.ObjectFactory):

    from omero_model_ShareMemberI import ShareMemberI

    def create(self, type):
        return self.ShareMemberI()

    def destroy(self):
        pass

class StageLabelObjectFactory(Ice.ObjectFactory):

    from omero_model_StageLabelI import StageLabelI

    def create(self, type):
        return self.StageLabelI()

    def destroy(self):
        pass

class StatsInfoObjectFactory(Ice.ObjectFactory):

    from omero_model_StatsInfoI import StatsInfoI

    def create(self, type):
        return self.StatsInfoI()

    def destroy(self):
        pass

class TagAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_TagAnnotationI import TagAnnotationI

    def create(self, type):
        return self.TagAnnotationI()

    def destroy(self):
        pass

class TermAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_TermAnnotationI import TermAnnotationI

    def create(self, type):
        return self.TermAnnotationI()

    def destroy(self):
        pass

class ThumbnailObjectFactory(Ice.ObjectFactory):

    from omero_model_ThumbnailI import ThumbnailI

    def create(self, type):
        return self.ThumbnailI()

    def destroy(self):
        pass

class ThumbnailGenerationJobObjectFactory(Ice.ObjectFactory):

    from omero_model_ThumbnailGenerationJobI import ThumbnailGenerationJobI

    def create(self, type):
        return self.ThumbnailGenerationJobI()

    def destroy(self):
        pass

class TimestampAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_TimestampAnnotationI import TimestampAnnotationI

    def create(self, type):
        return self.TimestampAnnotationI()

    def destroy(self):
        pass

class TransmittanceRangeObjectFactory(Ice.ObjectFactory):

    from omero_model_TransmittanceRangeI import TransmittanceRangeI

    def create(self, type):
        return self.TransmittanceRangeI()

    def destroy(self):
        pass

class UploadJobObjectFactory(Ice.ObjectFactory):

    from omero_model_UploadJobI import UploadJobI

    def create(self, type):
        return self.UploadJobI()

    def destroy(self):
        pass

class WellObjectFactory(Ice.ObjectFactory):

    from omero_model_WellI import WellI

    def create(self, type):
        return self.WellI()

    def destroy(self):
        pass

class WellAnnotationLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_WellAnnotationLinkI import WellAnnotationLinkI

    def create(self, type):
        return self.WellAnnotationLinkI()

    def destroy(self):
        pass

class WellReagentLinkObjectFactory(Ice.ObjectFactory):

    from omero_model_WellReagentLinkI import WellReagentLinkI

    def create(self, type):
        return self.WellReagentLinkI()

    def destroy(self):
        pass

class WellSampleObjectFactory(Ice.ObjectFactory):

    from omero_model_WellSampleI import WellSampleI

    def create(self, type):
        return self.WellSampleI()

    def destroy(self):
        pass

class XmlAnnotationObjectFactory(Ice.ObjectFactory):

    from omero_model_XmlAnnotationI import XmlAnnotationI

    def create(self, type):
        return self.XmlAnnotationI()

    def destroy(self):
        pass

class PermissionsObjectFactory(Ice.ObjectFactory):

    from omero_model_PermissionsI import PermissionsI

    def create(self, type):
        return self.PermissionsI()

    def destroy(self):
        pass

class DetailsObjectFactory(Ice.ObjectFactory):

    from omero_model_DetailsI import DetailsI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.DetailsI(self.client)

    def destroy(self):
        pass

class ElectricPotentialObjectFactory(Ice.ObjectFactory):

    from omero_model_ElectricPotentialI import ElectricPotentialI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.ElectricPotentialI()

    def destroy(self):
        pass

class FrequencyObjectFactory(Ice.ObjectFactory):

    from omero_model_FrequencyI import FrequencyI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.FrequencyI()

    def destroy(self):
        pass

class LengthObjectFactory(Ice.ObjectFactory):

    from omero_model_LengthI import LengthI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.LengthI()

    def destroy(self):
        pass

class PowerObjectFactory(Ice.ObjectFactory):

    from omero_model_PowerI import PowerI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.PowerI()

    def destroy(self):
        pass

class PressureObjectFactory(Ice.ObjectFactory):

    from omero_model_PressureI import PressureI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.PressureI()

    def destroy(self):
        pass

class TemperatureObjectFactory(Ice.ObjectFactory):

    from omero_model_TemperatureI import TemperatureI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.TemperatureI()

    def destroy(self):
        pass

class TimeObjectFactory(Ice.ObjectFactory):

    from omero_model_TimeI import TimeI

    def __init__(self, client = None):
        self.client = client

    def create(self, type):
        return self.TimeI()

    def destroy(self):
        pass

def conditionalAdd(name, ic, of):
    if not ic.findObjectFactory(name):
        ic.addObjectFactory(of, name)

def registerObjectFactory(ic, client = None):
    conditionalAdd("::omero::model::Permissions", ic, PermissionsObjectFactory())
    conditionalAdd("::omero::model::Details", ic, DetailsObjectFactory(client))
    conditionalAdd("::omero::model::ElectricPotential", ic, ElectricPotentialObjectFactory(client))
    conditionalAdd("::omero::model::Frequency", ic, FrequencyObjectFactory(client))
    conditionalAdd("::omero::model::Length", ic, LengthObjectFactory(client))
    conditionalAdd("::omero::model::Power", ic, PowerObjectFactory(client))
    conditionalAdd("::omero::model::Pressure", ic, PressureObjectFactory(client))
    conditionalAdd("::omero::model::Temperature", ic, TemperatureObjectFactory(client))
    conditionalAdd("::omero::model::Time", ic, TimeObjectFactory(client))
    conditionalAdd("::omero::model::AcquisitionMode", ic,  AcquisitionModeObjectFactory())
    conditionalAdd("::omero::model::AdminPrivilege", ic,  AdminPrivilegeObjectFactory())
    conditionalAdd("::omero::model::AffineTransform", ic,  AffineTransformObjectFactory())
    conditionalAdd("::omero::model::AnnotationAnnotationLink", ic,  AnnotationAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Arc", ic,  ArcObjectFactory())
    conditionalAdd("::omero::model::ArcType", ic,  ArcTypeObjectFactory())
    conditionalAdd("::omero::model::Binning", ic,  BinningObjectFactory())
    conditionalAdd("::omero::model::BooleanAnnotation", ic,  BooleanAnnotationObjectFactory())
    conditionalAdd("::omero::model::Channel", ic,  ChannelObjectFactory())
    conditionalAdd("::omero::model::ChannelAnnotationLink", ic,  ChannelAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ChannelBinding", ic,  ChannelBindingObjectFactory())
    conditionalAdd("::omero::model::ChecksumAlgorithm", ic,  ChecksumAlgorithmObjectFactory())
    conditionalAdd("::omero::model::CommentAnnotation", ic,  CommentAnnotationObjectFactory())
    conditionalAdd("::omero::model::ContrastMethod", ic,  ContrastMethodObjectFactory())
    conditionalAdd("::omero::model::ContrastStretchingContext", ic,  ContrastStretchingContextObjectFactory())
    conditionalAdd("::omero::model::Correction", ic,  CorrectionObjectFactory())
    conditionalAdd("::omero::model::DBPatch", ic,  DBPatchObjectFactory())
    conditionalAdd("::omero::model::Dataset", ic,  DatasetObjectFactory())
    conditionalAdd("::omero::model::DatasetAnnotationLink", ic,  DatasetAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::DatasetImageLink", ic,  DatasetImageLinkObjectFactory())
    conditionalAdd("::omero::model::Detector", ic,  DetectorObjectFactory())
    conditionalAdd("::omero::model::DetectorAnnotationLink", ic,  DetectorAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::DetectorSettings", ic,  DetectorSettingsObjectFactory())
    conditionalAdd("::omero::model::DetectorType", ic,  DetectorTypeObjectFactory())
    conditionalAdd("::omero::model::Dichroic", ic,  DichroicObjectFactory())
    conditionalAdd("::omero::model::DichroicAnnotationLink", ic,  DichroicAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::DimensionOrder", ic,  DimensionOrderObjectFactory())
    conditionalAdd("::omero::model::DoubleAnnotation", ic,  DoubleAnnotationObjectFactory())
    conditionalAdd("::omero::model::Ellipse", ic,  EllipseObjectFactory())
    conditionalAdd("::omero::model::Event", ic,  EventObjectFactory())
    conditionalAdd("::omero::model::EventLog", ic,  EventLogObjectFactory())
    conditionalAdd("::omero::model::EventType", ic,  EventTypeObjectFactory())
    conditionalAdd("::omero::model::Experiment", ic,  ExperimentObjectFactory())
    conditionalAdd("::omero::model::ExperimentType", ic,  ExperimentTypeObjectFactory())
    conditionalAdd("::omero::model::Experimenter", ic,  ExperimenterObjectFactory())
    conditionalAdd("::omero::model::ExperimenterAnnotationLink", ic,  ExperimenterAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ExperimenterGroup", ic,  ExperimenterGroupObjectFactory())
    conditionalAdd("::omero::model::ExperimenterGroupAnnotationLink", ic,  ExperimenterGroupAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ExternalInfo", ic,  ExternalInfoObjectFactory())
    conditionalAdd("::omero::model::Family", ic,  FamilyObjectFactory())
    conditionalAdd("::omero::model::Filament", ic,  FilamentObjectFactory())
    conditionalAdd("::omero::model::FilamentType", ic,  FilamentTypeObjectFactory())
    conditionalAdd("::omero::model::FileAnnotation", ic,  FileAnnotationObjectFactory())
    conditionalAdd("::omero::model::Fileset", ic,  FilesetObjectFactory())
    conditionalAdd("::omero::model::FilesetAnnotationLink", ic,  FilesetAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::FilesetEntry", ic,  FilesetEntryObjectFactory())
    conditionalAdd("::omero::model::FilesetJobLink", ic,  FilesetJobLinkObjectFactory())
    conditionalAdd("::omero::model::Filter", ic,  FilterObjectFactory())
    conditionalAdd("::omero::model::FilterAnnotationLink", ic,  FilterAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::FilterSet", ic,  FilterSetObjectFactory())
    conditionalAdd("::omero::model::FilterSetEmissionFilterLink", ic,  FilterSetEmissionFilterLinkObjectFactory())
    conditionalAdd("::omero::model::FilterSetExcitationFilterLink", ic,  FilterSetExcitationFilterLinkObjectFactory())
    conditionalAdd("::omero::model::FilterType", ic,  FilterTypeObjectFactory())
    conditionalAdd("::omero::model::Folder", ic,  FolderObjectFactory())
    conditionalAdd("::omero::model::FolderAnnotationLink", ic,  FolderAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::FolderImageLink", ic,  FolderImageLinkObjectFactory())
    conditionalAdd("::omero::model::FolderRoiLink", ic,  FolderRoiLinkObjectFactory())
    conditionalAdd("::omero::model::Format", ic,  FormatObjectFactory())
    conditionalAdd("::omero::model::GenericExcitationSource", ic,  GenericExcitationSourceObjectFactory())
    conditionalAdd("::omero::model::GroupExperimenterMap", ic,  GroupExperimenterMapObjectFactory())
    conditionalAdd("::omero::model::Illumination", ic,  IlluminationObjectFactory())
    conditionalAdd("::omero::model::Image", ic,  ImageObjectFactory())
    conditionalAdd("::omero::model::ImageAnnotationLink", ic,  ImageAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ImagingEnvironment", ic,  ImagingEnvironmentObjectFactory())
    conditionalAdd("::omero::model::Immersion", ic,  ImmersionObjectFactory())
    conditionalAdd("::omero::model::ImportJob", ic,  ImportJobObjectFactory())
    conditionalAdd("::omero::model::IndexingJob", ic,  IndexingJobObjectFactory())
    conditionalAdd("::omero::model::Instrument", ic,  InstrumentObjectFactory())
    conditionalAdd("::omero::model::InstrumentAnnotationLink", ic,  InstrumentAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::IntegrityCheckJob", ic,  IntegrityCheckJobObjectFactory())
    conditionalAdd("::omero::model::JobOriginalFileLink", ic,  JobOriginalFileLinkObjectFactory())
    conditionalAdd("::omero::model::JobStatus", ic,  JobStatusObjectFactory())
    conditionalAdd("::omero::model::Label", ic,  LabelObjectFactory())
    conditionalAdd("::omero::model::Laser", ic,  LaserObjectFactory())
    conditionalAdd("::omero::model::LaserMedium", ic,  LaserMediumObjectFactory())
    conditionalAdd("::omero::model::LaserType", ic,  LaserTypeObjectFactory())
    conditionalAdd("::omero::model::LightEmittingDiode", ic,  LightEmittingDiodeObjectFactory())
    conditionalAdd("::omero::model::LightPath", ic,  LightPathObjectFactory())
    conditionalAdd("::omero::model::LightPathAnnotationLink", ic,  LightPathAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::LightPathEmissionFilterLink", ic,  LightPathEmissionFilterLinkObjectFactory())
    conditionalAdd("::omero::model::LightPathExcitationFilterLink", ic,  LightPathExcitationFilterLinkObjectFactory())
    conditionalAdd("::omero::model::LightSettings", ic,  LightSettingsObjectFactory())
    conditionalAdd("::omero::model::LightSourceAnnotationLink", ic,  LightSourceAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Line", ic,  LineObjectFactory())
    conditionalAdd("::omero::model::Link", ic,  LinkObjectFactory())
    conditionalAdd("::omero::model::ListAnnotation", ic,  ListAnnotationObjectFactory())
    conditionalAdd("::omero::model::LogicalChannel", ic,  LogicalChannelObjectFactory())
    conditionalAdd("::omero::model::LongAnnotation", ic,  LongAnnotationObjectFactory())
    conditionalAdd("::omero::model::MapAnnotation", ic,  MapAnnotationObjectFactory())
    conditionalAdd("::omero::model::Mask", ic,  MaskObjectFactory())
    conditionalAdd("::omero::model::Medium", ic,  MediumObjectFactory())
    conditionalAdd("::omero::model::MetadataImportJob", ic,  MetadataImportJobObjectFactory())
    conditionalAdd("::omero::model::MicrobeamManipulation", ic,  MicrobeamManipulationObjectFactory())
    conditionalAdd("::omero::model::MicrobeamManipulationType", ic,  MicrobeamManipulationTypeObjectFactory())
    conditionalAdd("::omero::model::Microscope", ic,  MicroscopeObjectFactory())
    conditionalAdd("::omero::model::MicroscopeType", ic,  MicroscopeTypeObjectFactory())
    conditionalAdd("::omero::model::Namespace", ic,  NamespaceObjectFactory())
    conditionalAdd("::omero::model::NamespaceAnnotationLink", ic,  NamespaceAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Node", ic,  NodeObjectFactory())
    conditionalAdd("::omero::model::NodeAnnotationLink", ic,  NodeAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::OTF", ic,  OTFObjectFactory())
    conditionalAdd("::omero::model::Objective", ic,  ObjectiveObjectFactory())
    conditionalAdd("::omero::model::ObjectiveAnnotationLink", ic,  ObjectiveAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ObjectiveSettings", ic,  ObjectiveSettingsObjectFactory())
    conditionalAdd("::omero::model::OriginalFile", ic,  OriginalFileObjectFactory())
    conditionalAdd("::omero::model::OriginalFileAnnotationLink", ic,  OriginalFileAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ParseJob", ic,  ParseJobObjectFactory())
    conditionalAdd("::omero::model::Path", ic,  PathObjectFactory())
    conditionalAdd("::omero::model::PhotometricInterpretation", ic,  PhotometricInterpretationObjectFactory())
    conditionalAdd("::omero::model::PixelDataJob", ic,  PixelDataJobObjectFactory())
    conditionalAdd("::omero::model::Pixels", ic,  PixelsObjectFactory())
    conditionalAdd("::omero::model::PixelsOriginalFileMap", ic,  PixelsOriginalFileMapObjectFactory())
    conditionalAdd("::omero::model::PixelsType", ic,  PixelsTypeObjectFactory())
    conditionalAdd("::omero::model::PlaneInfo", ic,  PlaneInfoObjectFactory())
    conditionalAdd("::omero::model::PlaneInfoAnnotationLink", ic,  PlaneInfoAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::PlaneSlicingContext", ic,  PlaneSlicingContextObjectFactory())
    conditionalAdd("::omero::model::Plate", ic,  PlateObjectFactory())
    conditionalAdd("::omero::model::PlateAcquisition", ic,  PlateAcquisitionObjectFactory())
    conditionalAdd("::omero::model::PlateAcquisitionAnnotationLink", ic,  PlateAcquisitionAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::PlateAnnotationLink", ic,  PlateAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Point", ic,  PointObjectFactory())
    conditionalAdd("::omero::model::Polygon", ic,  PolygonObjectFactory())
    conditionalAdd("::omero::model::Polyline", ic,  PolylineObjectFactory())
    conditionalAdd("::omero::model::Project", ic,  ProjectObjectFactory())
    conditionalAdd("::omero::model::ProjectAnnotationLink", ic,  ProjectAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ProjectDatasetLink", ic,  ProjectDatasetLinkObjectFactory())
    conditionalAdd("::omero::model::ProjectionAxis", ic,  ProjectionAxisObjectFactory())
    conditionalAdd("::omero::model::ProjectionDef", ic,  ProjectionDefObjectFactory())
    conditionalAdd("::omero::model::ProjectionType", ic,  ProjectionTypeObjectFactory())
    conditionalAdd("::omero::model::Pulse", ic,  PulseObjectFactory())
    conditionalAdd("::omero::model::QuantumDef", ic,  QuantumDefObjectFactory())
    conditionalAdd("::omero::model::Reagent", ic,  ReagentObjectFactory())
    conditionalAdd("::omero::model::ReagentAnnotationLink", ic,  ReagentAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Rectangle", ic,  RectangleObjectFactory())
    conditionalAdd("::omero::model::RenderingDef", ic,  RenderingDefObjectFactory())
    conditionalAdd("::omero::model::RenderingModel", ic,  RenderingModelObjectFactory())
    conditionalAdd("::omero::model::ReverseIntensityContext", ic,  ReverseIntensityContextObjectFactory())
    conditionalAdd("::omero::model::Roi", ic,  RoiObjectFactory())
    conditionalAdd("::omero::model::RoiAnnotationLink", ic,  RoiAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Screen", ic,  ScreenObjectFactory())
    conditionalAdd("::omero::model::ScreenAnnotationLink", ic,  ScreenAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ScreenPlateLink", ic,  ScreenPlateLinkObjectFactory())
    conditionalAdd("::omero::model::ScriptJob", ic,  ScriptJobObjectFactory())
    conditionalAdd("::omero::model::Session", ic,  SessionObjectFactory())
    conditionalAdd("::omero::model::SessionAnnotationLink", ic,  SessionAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::ShapeAnnotationLink", ic,  ShapeAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::Share", ic,  ShareObjectFactory())
    conditionalAdd("::omero::model::ShareMember", ic,  ShareMemberObjectFactory())
    conditionalAdd("::omero::model::StageLabel", ic,  StageLabelObjectFactory())
    conditionalAdd("::omero::model::StatsInfo", ic,  StatsInfoObjectFactory())
    conditionalAdd("::omero::model::TagAnnotation", ic,  TagAnnotationObjectFactory())
    conditionalAdd("::omero::model::TermAnnotation", ic,  TermAnnotationObjectFactory())
    conditionalAdd("::omero::model::Thumbnail", ic,  ThumbnailObjectFactory())
    conditionalAdd("::omero::model::ThumbnailGenerationJob", ic,  ThumbnailGenerationJobObjectFactory())
    conditionalAdd("::omero::model::TimestampAnnotation", ic,  TimestampAnnotationObjectFactory())
    conditionalAdd("::omero::model::TransmittanceRange", ic,  TransmittanceRangeObjectFactory())
    conditionalAdd("::omero::model::UploadJob", ic,  UploadJobObjectFactory())
    conditionalAdd("::omero::model::Well", ic,  WellObjectFactory())
    conditionalAdd("::omero::model::WellAnnotationLink", ic,  WellAnnotationLinkObjectFactory())
    conditionalAdd("::omero::model::WellReagentLink", ic,  WellReagentLinkObjectFactory())
    conditionalAdd("::omero::model::WellSample", ic,  WellSampleObjectFactory())
    conditionalAdd("::omero::model::XmlAnnotation", ic,  XmlAnnotationObjectFactory())

